dreamtim package
================

Submodules
----------

dreamtim.calculator module
--------------------------

.. automodule:: dreamtim.calculator
   :members:
   :undoc-members:
   :show-inheritance:

dreamtim.statistical\_tools module
----------------------------------

.. automodule:: dreamtim.statistical_tools
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dreamtim
   :members:
   :undoc-members:
   :show-inheritance:
